@@ -9,7 +9,7 @@
 #
 
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 The SCons Foundation
+# Copyright (c) 2001 - 2020 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -29,66 +29,33 @@
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
 
-from __future__ import nested_scopes
-
-__revision__ = "src/script/scons-time.py 4720 2010/03/24 03:14:11 jars"
+__revision__ = "bin/scons-time.py c289977f8b34786ab6c334311e232886da7e8df1 2020-07-17 01:50:03 bdbaddog"
 
 import getopt
 import glob
 import os
-import os.path
 import re
 import shutil
-import string
 import sys
 import tempfile
 import time
 
-try:
-    False
-except NameError:
-    # Pre-2.2 Python has no False keyword.
-    import __builtin__
-    __builtin__.False = not 1
-
-try:
-    True
-except NameError:
-    # Pre-2.2 Python has no True keyword.
-    import __builtin__
-    __builtin__.True = not 0
-
-def make_temp_file(**kw):
-    try:
-        result = tempfile.mktemp(**kw)
-        try:
-            result = os.path.realpath(result)
-        except AttributeError:
-            # Python 2.1 has no os.path.realpath() method.
-            pass
-    except TypeError:
-        try:
-            save_template = tempfile.template
-            prefix = kw['prefix']
-            del kw['prefix']
-            tempfile.template = prefix
-            result = tempfile.mktemp(**kw)
-        finally:
-            tempfile.template = save_template
-    return result
 
 def HACK_for_exec(cmd, *args):
-    '''
+    """
     For some reason, Python won't allow an exec() within a function
     that also declares an internal function (including lambda functions).
     This function is a hack that calls exec() in a function with no
     internal functions.
-    '''
-    if not args:          exec(cmd)
-    elif len(args) == 1:  exec cmd in args[0]
-    else:                 exec cmd in args[0], args[1]
+    """
+    if not args:
+        exec(cmd)
+    elif len(args) == 1:
+        exec(cmd, args[0])
+    else:
+        exec(cmd, args[0], args[1])
+
 
 class Plotter:
     def increment_size(self, largest):
@@ -98,12 +65,12 @@ class Plotter:
         between 5 and 9 horizontal lines on the graph, on some set of
         boundaries that are multiples of 10/100/1000/etc.
         """
-        i = largest / 5
+        i = largest // 5
         if not i:
             return largest
         multiplier = 1
         while i >= 10:
-            i = i / 10
+            i = i // 10
             multiplier = multiplier * 10
         return i * multiplier
 
@@ -111,7 +78,8 @@ class Plotter:
         # Round up to next integer.
         largest = int(largest) + 1
         increment = self.increment_size(largest)
-        return ((largest + increment - 1) / increment) * increment
+        return ((largest + increment - 1) // increment) * increment
+
 
 class Line:
     def __init__(self, points, type, title, label, comment, fmt="%s %s"):
@@ -124,7 +92,7 @@ class Line:
 
     def print_label(self, inx, x, y):
         if self.label:
-            print 'set label %s "%s" at %s,%s right' % (inx, self.label, x, y)
+            print('set label %s "%s" at %0.1f,%0.1f right' % (inx, self.label, x, y))
 
     def plot_string(self):
         if self.title:
@@ -137,21 +105,22 @@ class Line:
         if fmt is None:
             fmt = self.fmt
         if self.comment:
-            print '# %s' % self.comment
+            print('# %s' % self.comment)
         for x, y in self.points:
             # If y is None, it usually represents some kind of break
             # in the line's index number.  We might want to represent
             # this some way rather than just drawing the line straight
             # between the two points on either side.
-            if not y is None:
-                print fmt % (x, y)
-        print 'e'
+            if y is not None:
+                print(fmt % (x, y))
+        print('e')
 
     def get_x_values(self):
-        return [ p[0] for p in self.points ]
+        return [p[0] for p in self.points]
 
     def get_y_values(self):
-        return [ p[1] for p in self.points ]
+        return [p[1] for p in self.points]
+
 
 class Gnuplotter(Plotter):
 
@@ -169,7 +138,7 @@ class Gnuplotter(Plotter):
         return line.plot_string()
 
     def vertical_bar(self, x, type, label, comment):
-        if self.get_min_x() <= x and x <= self.get_max_x():
+        if self.get_min_x() <= x <= self.get_max_x():
             points = [(x, 0), (x, self.max_graph_value(self.get_max_y()))]
             self.line(points, type, label, comment)
 
@@ -177,13 +146,13 @@ class Gnuplotter(Plotter):
         result = []
         for line in self.lines:
             result.extend(line.get_x_values())
-        return filter(lambda r: not r is None, result)
+        return [r for r in result if r is not None]
 
     def get_all_y_values(self):
         result = []
         for line in self.lines:
             result.extend(line.get_y_values())
-        return filter(lambda r: not r is None, result)
+        return [r for r in result if r is not None]
 
     def get_min_x(self):
         try:
@@ -231,30 +200,28 @@ class Gnuplotter(Plotter):
             return
 
         if self.title:
-            print 'set title "%s"' % self.title
-        print 'set key %s' % self.key_location
+            print('set title "%s"' % self.title)
+        print('set key %s' % self.key_location)
 
         min_y = self.get_min_y()
         max_y = self.max_graph_value(self.get_max_y())
-        range = max_y - min_y
-        incr = range / 10.0
+        incr = (max_y - min_y) / 10.0
         start = min_y + (max_y / 2.0) + (2.0 * incr)
-        position = [ start - (i * incr) for i in xrange(5) ]
+        position = [start - (i * incr) for i in range(5)]
 
         inx = 1
         for line in self.lines:
-            line.print_label(inx, line.points[0][0]-1,
-                             position[(inx-1) % len(position)])
+            line.print_label(inx, line.points[0][0] - 1,
+                             position[(inx - 1) % len(position)])
             inx += 1
 
-        plot_strings = [ self.plot_string(l) for l in self.lines ]
-        print 'plot ' + ', \\\n     '.join(plot_strings)
+        plot_strings = [self.plot_string(l) for l in self.lines]
+        print('plot ' + ', \\\n     '.join(plot_strings))
 
         for line in self.lines:
             line.print_points()
 
 
-
 def untar(fname):
     import tarfile
     tar = tarfile.open(name=fname, mode='r')
@@ -262,6 +229,7 @@ def untar(fname):
         tar.extract(tarinfo)
     tar.close()
 
+
 def unzip(fname):
     import zipfile
     zf = zipfile.ZipFile(fname, 'r')
@@ -269,26 +237,29 @@ def unzip(fname):
         dir = os.path.dirname(name)
         try:
             os.makedirs(dir)
-        except:
+        except OSError:
             pass
-        open(name, 'w').write(zf.read(name))
+        with open(name, 'wb') as f:
+            f.write(zf.read(name))
+
 
 def read_tree(dir):
-    def read_files(arg, dirname, fnames):
-        for fn in fnames:
-            fn = os.path.join(dirname, fn)
+    for dirpath, dirnames, filenames in os.walk(dir):
+        for fn in filenames:
+            fn = os.path.join(dirpath, fn)
             if os.path.isfile(fn):
-                open(fn, 'rb').read()
-    os.path.walk('.', read_files, None)
+                with open(fn, 'rb') as f:
+                    f.read()
+
 
 def redirect_to_file(command, log):
     return '%s > %s 2>&1' % (command, log)
 
+
 def tee_to_file(command, log):
     return '%s 2>&1 | tee %s' % (command, log)
 
 
-    
 class SConsTimer:
     """
     Usage: scons-time SUBCOMMAND [ARGUMENTS]
@@ -304,47 +275,45 @@ class SConsTimer:
     """
 
     name = 'scons-time'
-    name_spaces = ' '*len(name)
+    name_spaces = ' ' * len(name)
 
     def makedict(**kw):
         return kw
 
     default_settings = makedict(
-        aegis               = 'aegis',
-        aegis_project       = None,
-        chdir               = None,
-        config_file         = None,
-        initial_commands    = [],
-        key_location        = 'bottom left',
-        orig_cwd            = os.getcwd(),
-        outdir              = None,
-        prefix              = '',
-        python              = '"%s"' % sys.executable,
-        redirect            = redirect_to_file,
-        scons               = None,
-        scons_flags         = '--debug=count --debug=memory --debug=time --debug=memoizer',
-        scons_lib_dir       = None,
-        scons_wrapper       = None,
-        startup_targets     = '--help',
-        subdir              = None,
-        subversion_url      = None,
-        svn                 = 'svn',
-        svn_co_flag         = '-q',
-        tar                 = 'tar',
-        targets             = '',
-        targets0            = None,
-        targets1            = None,
-        targets2            = None,
-        title               = None,
-        unzip               = 'unzip',
-        verbose             = False,
-        vertical_bars       = [],
+        chdir=None,
+        config_file=None,
+        initial_commands=[],
+        key_location='bottom left',
+        orig_cwd=os.getcwd(),
+        outdir=None,
+        prefix='',
+        python='"%s"' % sys.executable,
+        redirect=redirect_to_file,
+        scons=None,
+        scons_flags='--debug=count --debug=memory --debug=time --debug=memoizer',
+        scons_lib_dir=None,
+        scons_wrapper=None,
+        startup_targets='--help',
+        subdir=None,
+        subversion_url=None,
+        svn='svn',
+        svn_co_flag='-q',
+        tar='tar',
+        targets='',
+        targets0=None,
+        targets1=None,
+        targets2=None,
+        title=None,
+        unzip='unzip',
+        verbose=False,
+        vertical_bars=[],
 
-        unpack_map = {
-            '.tar.gz'       : (untar,   '%(tar)s xzf %%s'),
-            '.tgz'          : (untar,   '%(tar)s xzf %%s'),
-            '.tar'          : (untar,   '%(tar)s xf %%s'),
-            '.zip'          : (unzip,   '%(unzip)s %%s'),
+        unpack_map={
+            '.tar.gz': (untar, '%(tar)s xzf %%s'),
+            '.tgz': (untar, '%(tar)s xzf %%s'),
+            '.tar': (untar, '%(tar)s xf %%s'),
+            '.zip': (unzip, '%(unzip)s %%s'),
         },
     )
 
@@ -368,10 +337,10 @@ class SConsTimer:
     ]
 
     stage_strings = {
-        'pre-read'      : 'Memory before reading SConscript files:',
-        'post-read'     : 'Memory after reading SConscript files:',
-        'pre-build'     : 'Memory before building targets:',
-        'post-build'    : 'Memory after building targets:',
+        'pre-read': 'Memory before reading SConscript files:',
+        'post-read': 'Memory after reading SConscript files:',
+        'pre-build': 'Memory before building targets:',
+        'post-build': 'Memory after building targets:',
     }
 
     memory_string_all = 'Memory '
@@ -379,12 +348,12 @@ class SConsTimer:
     default_stage = stages[-1]
 
     time_strings = {
-        'total'         : 'Total build time',
-        'SConscripts'   : 'Total SConscript file execution time',
-        'SCons'         : 'Total SCons execution time',
-        'commands'      : 'Total command execution time',
+        'total': 'Total build time',
+        'SConscripts': 'Total SConscript file execution time',
+        'SCons': 'Total SCons execution time',
+        'commands': 'Total command execution time',
     }
-    
+
     time_string_all = 'Total .* time'
 
     #
@@ -464,7 +433,7 @@ class SConsTimer:
         Executes a list of commands, substituting values from the
         specified dictionary.
         """
-        commands = [ self.subst_variables(c, dict) for c in commands ]
+        commands = [self.subst_variables(c, dict) for c in commands]
         for action, string, args in commands:
             self.display(string, *args)
             sys.stdout.flush()
@@ -480,12 +449,20 @@ class SConsTimer:
 
     def log_execute(self, command, log):
         command = self.subst(command, self.__dict__)
-        output = os.popen(command).read()
+        p = os.popen(command)
+        output = p.read()
+        p.close()
+        # TODO: convert to subrocess, os.popen is obsolete. This didn't work:
+        # process = subprocess.Popen(command, stdout=subprocess.PIPE, shell=True)
+        # output = process.stdout.read()
+        # process.stdout.close()
+        # process.wait()
         if self.verbose:
             sys.stdout.write(output)
-        open(log, 'wb').write(output)
-
-    #
+        # TODO: Figure out
+        # Not sure we need to write binary here
+        with open(log, 'w') as f:
+            f.write(str(output))
 
     def archive_splitext(self, path):
         """
@@ -506,9 +483,7 @@ class SConsTimer:
         """
         files = []
         for a in args:
-            g = glob.glob(a)
-            g.sort()
-            files.extend(g)
+            files.extend(sorted(glob.glob(a)))
 
         if tail:
             files = files[-tail:]
@@ -522,7 +497,7 @@ class SConsTimer:
         header_fmt = ' '.join(['%12s'] * len(columns))
         line_fmt = header_fmt + '    %s'
 
-        print header_fmt % columns
+        print(header_fmt % columns)
 
         for file in files:
             t = line_function(file, *args, **kw)
@@ -532,14 +507,14 @@ class SConsTimer:
             if diff > 0:
                 t += [''] * diff
             t.append(file_function(file))
-            print line_fmt % tuple(t)
+            print(line_fmt % tuple(t))
 
     def collect_results(self, files, function, *args, **kw):
         results = {}
 
         for file in files:
             base = os.path.splitext(file)[0]
-            run, index = string.split(base, '-')[-2:]
+            run, index = base.split('-')[-2:]
 
             run = int(run)
             index = int(index)
@@ -577,11 +552,11 @@ class SConsTimer:
         and returns the next run number after the largest it finds.
         """
         x = re.compile(re.escape(prefix) + '-([0-9]+).*')
-        matches = map(lambda e, x=x: x.match(e), os.listdir(dir))
-        matches = filter(None, matches)
+        matches = [x.match(e) for e in os.listdir(dir)]
+        matches = [_f for _f in matches if _f]
         if not matches:
             return 0
-        run_numbers = map(lambda m: int(m.group(1)), matches)
+        run_numbers = [int(m.group(1)) for m in matches]
         return int(max(run_numbers)) + 1
 
     def gnuplot_results(self, results, fmt='%s %.3f'):
@@ -590,16 +565,13 @@ class SConsTimer:
         """
         gp = Gnuplotter(self.title, self.key_location)
 
-        indices = results.keys()
-        indices.sort()
-
-        for i in indices:
+        for i in sorted(results.keys()):
             try:
                 t = self.run_titles[i]
             except IndexError:
                 t = '??? %s ???' % i
             results[i].sort()
-            gp.line(results[i], i+1, t, None, t, fmt=fmt)
+            gp.line(results[i], i + 1, t, None, t, fmt=fmt)
 
         for bar_tuple in self.vertical_bars:
             try:
@@ -628,11 +600,13 @@ class SConsTimer:
         if lines[0] == '':
             lines = lines[1:]
         spaces = re.match(' *', lines[0]).group(0)
-        def strip_initial_spaces(l, s=spaces):
-            if l.startswith(spaces):
-                l = l[len(spaces):]
-            return l
-        return '\n'.join([ strip_initial_spaces(l) for l in lines ]) + '\n'
+
+        def strip_initial_spaces(line, s=spaces):
+            if line.startswith(spaces):
+                line = line[len(spaces):]
+            return line
+
+        return '\n'.join([strip_initial_spaces(l) for l in lines]) + '\n'
 
     def profile_name(self, invocation):
         """
@@ -655,13 +629,14 @@ class SConsTimer:
             search_string = self.time_string_all
         else:
             search_string = time_string
-        contents = open(file).read()
+        with open(file) as f:
+            contents = f.read()
         if not contents:
             sys.stderr.write('file %s has no contents!\n' % repr(file))
             return None
-        result = re.findall(r'%s: ([\d\.]*)' % search_string, contents)[-4:]
-        result = [ float(r) for r in result ]
-        if not time_string is None:
+        result = re.findall(r'%s: ([\d.]*)' % search_string, contents)[-4:]
+        result = [float(r) for r in result]
+        if time_string is not None:
             try:
                 result = result[0]
             except IndexError:
@@ -675,13 +650,13 @@ class SConsTimer:
         """
         try:
             import pstats
-        except ImportError, e:
+        except ImportError as e:
             sys.stderr.write('%s: func: %s\n' % (self.name, e))
             sys.stderr.write('%s  This version of Python is missing the profiler.\n' % self.name_spaces)
             sys.stderr.write('%s  Cannot use the "func" subcommand.\n' % self.name_spaces)
             sys.exit(1)
         statistics = pstats.Stats(file).stats
-        matches = [ e for e in statistics.items() if e[0][2] == function ]
+        matches = [e for e in statistics.items() if e[0][2] == function]
         r = matches[0]
         return r[0][0], r[0][1], r[0][2], r[1][3]
 
@@ -700,9 +675,10 @@ class SConsTimer:
             search_string = self.memory_string_all
         else:
             search_string = memory_string
-        lines = open(file).readlines()
-        lines = [ l for l in lines if l.startswith(search_string) ][-4:]
-        result = [ int(l.split()[-1]) for l in lines[-4:] ]
+        with open(file) as f:
+            lines = f.readlines()
+        lines = [l for l in lines if l.startswith(search_string)][-4:]
+        result = [int(l.split()[-1]) for l in lines[-4:]]
         if len(result) == 1:
             result = result[0]
         return result
@@ -712,15 +688,14 @@ class SConsTimer:
         Returns the counts of the specified object_name.
         """
         object_string = ' ' + object_name + '\n'
-        lines = open(file).readlines()
-        line = [ l for l in lines if l.endswith(object_string) ][0]
-        result = [ int(field) for field in line.split()[:4] ]
+        with open(file) as f:
+            lines = f.readlines()
+        line = [l for l in lines if l.endswith(object_string)][0]
+        result = [int(field) for field in line.split()[:4]]
         if index is not None:
             result = result[index]
         return result
 
-    #
-
     command_alias = {}
 
     def execute_subcommand(self, argv):
@@ -736,7 +711,7 @@ class SConsTimer:
             return self.default(argv)
         try:
             return func(argv)
-        except TypeError, e:
+        except TypeError as e:
             sys.stderr.write("%s %s: %s\n" % (self.name, cmdName, e))
             import traceback
             traceback.print_exc(file=sys.stderr)
@@ -841,7 +816,9 @@ class SConsTimer:
                 self.title = a
 
         if self.config_file:
-            exec open(self.config_file, 'rU').read() in self.__dict__
+            with open(self.config_file, 'r') as f:
+                config = f.read()
+            exec(config, self.__dict__)
 
         if self.chdir:
             os.chdir(self.chdir)
@@ -873,14 +850,14 @@ class SConsTimer:
             for file in args:
                 try:
                     f, line, func, time = \
-                            self.get_function_profile(file, function_name)
-                except ValueError, e:
+                        self.get_function_profile(file, function_name)
+                except ValueError as e:
                     sys.stderr.write("%s: func: %s: %s\n" %
                                      (self.name, file, e))
                 else:
                     if f.startswith(cwd_):
                         f = f[len(cwd_):]
-                    print "%.3f %s:%d(%s)" % (time, f, line, func)
+                    print("%.3f %s:%d(%s)" % (time, f, line, func))
 
         elif format == 'gnuplot':
 
@@ -917,7 +894,11 @@ class SConsTimer:
     def do_mem(self, argv):
 
         format = 'ascii'
-        logfile_path = lambda x: x
+        def _logfile_path(x):
+            return x
+
+        logfile_path = _logfile_path
+
         stage = self.default_stage
         tail = None
 
@@ -950,7 +931,7 @@ class SConsTimer:
             elif o in ('-p', '--prefix'):
                 self.prefix = a
             elif o in ('--stage',):
-                if not a in self.stages:
+                if a not in self.stages:
                     sys.stderr.write('%s: mem: Unrecognized stage "%s".\n' % (self.name, a))
                     sys.exit(1)
                 stage = a
@@ -960,14 +941,18 @@ class SConsTimer:
                 self.title = a
 
         if self.config_file:
-            HACK_for_exec(open(self.config_file, 'rU').read(), self.__dict__)
+            with open(self.config_file, 'r') as f:
+                config = f.read()
+            HACK_for_exec(config, self.__dict__)
 
         if self.chdir:
             os.chdir(self.chdir)
-            logfile_path = lambda x, c=self.chdir: os.path.join(c, x)
+            def _logfile_path_join(x):
+                return os.path.join(self.chdir, x)
+
+            logfile_path = _logfile_path_join
 
         if not args:
-
             pattern = '%s*.log' % self.prefix
             args = self.args_to_files([pattern], tail)
 
@@ -986,7 +971,7 @@ class SConsTimer:
 
             args = self.args_to_files(args, tail)
 
-        cwd_ = os.getcwd() + os.sep
+        # cwd_ = os.getcwd() + os.sep
 
         if format == 'ascii':
 
@@ -1029,7 +1014,12 @@ class SConsTimer:
     def do_obj(self, argv):
 
         format = 'ascii'
-        logfile_path = lambda x: x
+
+        def _logfile_path(x):
+            return x
+
+        logfile_path = _logfile_path
+
         stage = self.default_stage
         tail = None
 
@@ -1062,7 +1052,7 @@ class SConsTimer:
             elif o in ('-p', '--prefix'):
                 self.prefix = a
             elif o in ('--stage',):
-                if not a in self.stages:
+                if a not in self.stages:
                     sys.stderr.write('%s: obj: Unrecognized stage "%s".\n' % (self.name, a))
                     sys.stderr.write('%s       Type "%s help obj" for help.\n' % (self.name_spaces, self.name))
                     sys.exit(1)
@@ -1080,14 +1070,19 @@ class SConsTimer:
         object_name = args.pop(0)
 
         if self.config_file:
-            HACK_for_exec(open(self.config_file, 'rU').read(), self.__dict__)
+            with open(self.config_file, 'r') as f:
+                config = f.read()
+            HACK_for_exec(config, self.__dict__)
 
         if self.chdir:
             os.chdir(self.chdir)
-            logfile_path = lambda x, c=self.chdir: os.path.join(c, x)
+
+            def _logfile_path_join(x):
+                return os.path.join(self.chdir, x)
+
+            logfile_path = _logfile_path_join
 
         if not args:
-
             pattern = '%s*.log' % self.prefix
             args = self.args_to_files([pattern], tail)
 
@@ -1138,7 +1133,6 @@ class SConsTimer:
         help = """\
         Usage: scons-time run [OPTIONS] [FILE ...]
 
-          --aegis=PROJECT               Use SCons from the Aegis PROJECT
           --chdir=DIR                   Name of unpacked directory for chdir
           -f FILE, --file=FILE          Read configuration from specified FILE
           -h, --help                    Print this help and exit
@@ -1163,7 +1157,6 @@ class SConsTimer:
         short_opts = '?f:hnp:qs:v'
 
         long_opts = [
-            'aegis=',
             'file=',
             'help',
             'no-exec',
@@ -1182,9 +1175,7 @@ class SConsTimer:
         opts, args = getopt.getopt(argv[1:], short_opts, long_opts)
 
         for o, a in opts:
-            if o in ('--aegis',):
-                self.aegis_project = a
-            elif o in ('-f', '--file'):
+            if o in ('-f', '--file'):
                 self.config_file = a
             elif o in ('-?', '-h', '--help'):
                 self.do_help(['help', 'run'])
@@ -1218,7 +1209,9 @@ class SConsTimer:
             sys.exit(1)
 
         if self.config_file:
-            exec open(self.config_file, 'rU').read() in self.__dict__
+            with open(self.config_file, 'r') as f:
+                config = f.read()
+            exec(config, self.__dict__)
 
         if args:
             self.archive_list = args
@@ -1234,8 +1227,6 @@ class SConsTimer:
         prepare = None
         if self.subversion_url:
             prepare = self.prep_subversion_run
-        elif self.aegis_project:
-            prepare = self.prep_aegis_run
 
         for run_number in run_number_list:
             self.individual_run(run_number, self.archive_list, prepare)
@@ -1248,39 +1239,27 @@ class SConsTimer:
             except ValueError:
                 result.append(int(n))
             else:
-                result.extend(range(int(x), int(y)+1))
+                result.extend(list(range(int(x), int(y) + 1)))
         return result
 
     def scons_path(self, dir):
-        return os.path.join(dir, 'src', 'script', 'scons.py')
+        return os.path.join(dir, 'scripts', 'scons.py')
 
     def scons_lib_dir_path(self, dir):
-        return os.path.join(dir, 'src', 'engine')
+        """build the path to the engine.
 
-    def prep_aegis_run(self, commands, removals):
-        self.aegis_tmpdir = make_temp_file(prefix = self.name + '-aegis-')
-        removals.append((shutil.rmtree, 'rm -rf %%s', self.aegis_tmpdir))
-
-        self.aegis_parent_project = os.path.splitext(self.aegis_project)[0]
-        self.scons = self.scons_path(self.aegis_tmpdir)
-        self.scons_lib_dir = self.scons_lib_dir_path(self.aegis_tmpdir)
-
-        commands.extend([
-            'mkdir %(aegis_tmpdir)s',
-            (lambda: os.chdir(self.aegis_tmpdir), 'cd %(aegis_tmpdir)s'),
-            '%(aegis)s -cp -ind -p %(aegis_parent_project)s .',
-            '%(aegis)s -cp -ind -p %(aegis_project)s -delta %(run_number)s .',
-        ])
+        this used to join src/engine, but no longer.
+        """
+        return dir
 
     def prep_subversion_run(self, commands, removals):
-        self.svn_tmpdir = make_temp_file(prefix = self.name + '-svn-')
+        self.svn_tmpdir = tempfile.mkdtemp(prefix=self.name + '-svn-')
         removals.append((shutil.rmtree, 'rm -rf %%s', self.svn_tmpdir))
 
         self.scons = self.scons_path(self.svn_tmpdir)
         self.scons_lib_dir = self.scons_lib_dir_path(self.svn_tmpdir)
 
         commands.extend([
-            'mkdir %(svn_tmpdir)s',
             '%(svn)s co %(svn_co_flag)s -r %(run_number)s %(subversion_url)s %(svn_tmpdir)s',
         ])
 
@@ -1295,9 +1274,9 @@ class SConsTimer:
         if prepare:
             prepare(commands, removals)
 
-        save_scons              = self.scons
-        save_scons_wrapper      = self.scons_wrapper
-        save_scons_lib_dir      = self.scons_lib_dir
+        save_scons = self.scons
+        save_scons_wrapper = self.scons_wrapper
+        save_scons_lib_dir = self.scons_lib_dir
 
         if self.outdir is None:
             self.outdir = self.orig_cwd
@@ -1327,11 +1306,9 @@ class SConsTimer:
         if self.targets2 is None:
             self.targets2 = self.targets
 
-        self.tmpdir = make_temp_file(prefix = self.name + '-')
+        self.tmpdir = tempfile.mkdtemp(prefix=self.name + '-')
 
         commands.extend([
-            'mkdir %(tmpdir)s',
-
             (os.chdir, 'cd %%s', self.tmpdir),
         ])
 
@@ -1358,7 +1335,7 @@ class SConsTimer:
 
         commands.extend([
             (lambda: read_tree('.'),
-            'find * -type f | xargs cat > /dev/null'),
+             'find * -type f | xargs cat > /dev/null'),
 
             (self.set_env, 'export %%s=%%s',
              'SCONS_LIB_DIR', self.scons_lib_dir),
@@ -1384,14 +1361,13 @@ class SConsTimer:
 
         if not os.environ.get('PRESERVE'):
             commands.extend(removals)
-
             commands.append((shutil.rmtree, 'rm -rf %%s', self.tmpdir))
 
         self.run_command_list(commands, self.__dict__)
 
-        self.scons              = save_scons
-        self.scons_lib_dir      = save_scons_lib_dir
-        self.scons_wrapper      = save_scons_wrapper
+        self.scons = save_scons
+        self.scons_lib_dir = save_scons_lib_dir
+        self.scons_wrapper = save_scons_wrapper
 
     #
 
@@ -1414,7 +1390,12 @@ class SConsTimer:
     def do_time(self, argv):
 
         format = 'ascii'
-        logfile_path = lambda x: x
+
+        def _logfile_path(x):
+            return x
+
+        logfile_path = _logfile_path
+
         tail = None
         which = 'total'
 
@@ -1451,21 +1432,26 @@ class SConsTimer:
             elif o in ('--title',):
                 self.title = a
             elif o in ('--which',):
-                if not a in self.time_strings.keys():
+                if a not in list(self.time_strings.keys()):
                     sys.stderr.write('%s: time: Unrecognized timer "%s".\n' % (self.name, a))
                     sys.stderr.write('%s  Type "%s help time" for help.\n' % (self.name_spaces, self.name))
                     sys.exit(1)
                 which = a
 
         if self.config_file:
-            HACK_for_exec(open(self.config_file, 'rU').read(), self.__dict__)
+            with open(self.config_file, 'r') as f:
+                config = f.read()
+            HACK_for_exec(config, self.__dict__)
 
         if self.chdir:
             os.chdir(self.chdir)
-            logfile_path = lambda x, c=self.chdir: os.path.join(c, x)
+
+            def _logfile_path_join(x):
+                return os.path.join(self.chdir, x)
+
+            logfile_path = _logfile_path_join
 
         if not args:
-
             pattern = '%s*.log' % self.prefix
             args = self.args_to_files([pattern], tail)
 
@@ -1503,6 +1489,7 @@ class SConsTimer:
             sys.stderr.write('%s: time: Unknown format "%s".\n' % (self.name, format))
             sys.exit(1)
 
+
 if __name__ == '__main__':
     opts, args = getopt.getopt(sys.argv[1:], 'h?V', ['help', 'version'])
 
